% Lebesgue constants demo 

clear;

% region

% % lune parameters
% x1=0;y1=0;r1=1;x2=0.5;y2=0;r2=0.8;

% symm sector
omega=pi;
r1=0;r2=1;a=0;b=0;A=[r2 0;r1 0]; B=[0 r2;0 r1]; C=[a b;a b];

% % circular zone
% alpha=pi/6;beta=pi/2;
% r=1;a=0;b=0;A=[r 0;-r 0]; B=[0 r;0 r]; C=[a b;a b];

% % circular segment
% omega=pi;
% r=1;a=0;b=0;A=[r 0;r 0]; B=[0 r;0 -r]; C=[a b;a b];

% % symm lens
% omega=pi/3;
% r=1;a=0;b=0;delta=2*cos(omega);
% A=[r 0;-r 0]; B=[0 r;0 r]; C=[a b;a+delta b];

% % butterfly
% omega=pi/3;
% r=1;a=0;b=0;
% A=[r 0;-r 0]; B=[0 r;0 -r]; C=[a b;a b];

degmin=3;degmax=24;step=3;

for n=degmin:step:degmax
    
% wam 
% % lune
% wam=wamlune(n,x1,y1,r1,x2,y2,r2);

% arc blending
wam=wamblend(n,A,B,C,-omega,omega);

degree=n

% approximate Fekete points
fek=dexsets(n,wam,0,[ ]);

% % discrete Leja points
leja=dexsets(n,wam,1,[ ]);

% estimating the Lebesgue constants
tol=0.01;ratio1=0;ratio2=0;ratio3=0;

% interpolation at approximate Fekete points
k=2;
while abs(ratio1-1)>tol 
% cmesh=wamlune(k*n,x1,y1,r1,x2,y2,r2);
cmesh=wamblend(k*n,A,B,C,-omega,omega);
leb1(k)=wamleb(n,fek,cmesh,[ ]);
if k>2
ratio1=leb1(k)/leb1(k-1);
end;
k=k+1;
end;
lebfek(n)=leb1(k-1);
fekete=lebfek(n)

% interpolation at discrete Leja points
k=2;
while abs(ratio2-1)>tol 
% cmesh=wamlune(k*n,x1,y1,r1,x2,y2,r2);
cmesh=wamblend(k*n,A,B,C,-omega,omega);
leb2(k)=wamleb(n,leja,cmesh,[ ]);
if k>2
ratio2=leb2(k)/leb2(k-1);
end;
k=k+1;
end;
lebleja(n)=leb2(k-1);
leja=lebleja(n)

% least-squares fitting on the wam
k=2;
while abs(ratio3-1)>tol 
% cmesh=wamlune(k*n,x1,y1,r1,x2,y2,r2);
cmesh=wamblend(k*n,A,B,C,-omega,omega);
leb3(k)=wamleb(n,wam,cmesh,[ ]);
if k>2
ratio3=leb3(k)/leb3(k-1);
end;
k=k+1;
end;
lebls(n)=wamleb(n,wam,cmesh,[ ]);
ls=lebls(n)

end

clf;
plot((degmin:step:degmax),lebfek(degmin:step:degmax),'-o');
hold on;
plot((degmin:step:degmax),lebleja(degmin:step:degmax),'-^');
plot((degmin:step:degmax),lebls(degmin:step:degmax),'-s');


