function wam=wamlissa(deg);

% computes a 3d WAM (Weakly Admissible Mesh) for polynomials of degree not 
% exceeding deg, on Lissajous curves of [-1,1]^3

% by Stefano De Marchi and Marco Vianello, University of Padova
% February 2015 

% input
% deg: polynomial degree

% ouput
% wam: 3-column array of mesh points

% parameters a,b,c of the Lissajous curve 
% (cos(a*t),cos(b*t),cos(c*t)), t in [0,pi] 
if mod(deg,2) == 0
a=3/4*deg^2+deg/2;b=3/4*deg^2+deg;c=3/4*deg^2+3/2*deg+1;
else
a=3/4*deg^2+1/4;b=3/4*deg^2+3/2*deg-1/4;c=3/4*deg^2+3/2*deg+3/4; 
end;

% sampling angles 
mu=c*deg+1;
theta=(0:mu)*pi/mu;

% mesh points
wam=[cos(a*theta') cos(b*theta') cos(c*theta')];


end


